==> ftape-1.13b.tar.gz: ftape-1.13b/ftape-io.h <==
#ifndef _FTAPE_IO_H
#define _FTAPE_IO_H

/*
 * Copyright (C) 1993,1994 Bas Laarhoven.

This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2, or (at your option)
any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; see the file COPYING.  If not, write to
the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.

 *
 $Source: /usr/src/distr/ftape-1.13/RCS/ftape-io.h,v $
 $Author: bas $
 *
 $Revision: 1.23 $
 $Date: 1994/06/12 16:07:53 $
 $State: Beta $
 *
 *      This file contains definitions for the glue part
 *      of the QIC-40/80 floppy-tape driver for Linux.
 */

struct error_info {
  int used;                     /* any reading or writing done */
  /* isr statistics */
  unsigned int id_am_errors;    /* id address mark not found */
  unsigned int id_crc_errors;   /* crc error in id address mark */
  unsigned int data_am_errors;  /* data address mark not found */
  unsigned int data_crc_errors; /* crc error in data field */
  unsigned int overrun_errors;  /* fdc access timing problem */
  unsigned int no_data_errors;  /* sector not found */
  unsigned int retries;         /* number of tape retries */
  /* ecc statistics */
  unsigned int crc_errors;      /* crc error in data */
  unsigned int crc_failures;    /* bad data without crc error */
  unsigned int ecc_failures;    /* failed to correct */
  unsigned int corrected;       /* total sectors corrected */
  /* general statistics */
  unsigned int rewinds;         /* number of tape rewinds */
};

/*
 *      ftape-io.c defined global vars.
 */
extern int ftape_failure;
extern int ftape_track;
extern int segments_per_track;
extern int segments_per_head;
extern int segments_per_cylinder;
extern int sectors_per_segment;
extern int tracks_per_tape;
extern int ftape_seg_pos;
extern int first_data_segment;
extern int ftape_state;
extern struct _fdt_id location;
extern int unknown_drive_config;
extern struct error_info history;
extern int write_protected;

/*
 *      ftape-io.c defined global functions.
 */
extern int ftape_command( int command);
extern int ftape_command_wait( int command, int timeout, int* status);
extern int ftape_report_drive_status( int *status);
extern int ftape_report_status( int* status);
extern int ftape_interrupt_wait( int time);
extern int _ftape_open( void);
extern int _ftape_close( void);
extern int _ftape_ioctl( unsigned int command, void * arg);
extern int ftape_ready_wait( int timeout, int* status);
extern int ftape_seek_head_to_track( int track);
extern void ftape_sleep( unsigned int time);
extern int ftape_parameter( int command);
extern int ftape_new_cartridge( void);
extern int ftape_abort_operation( int* location);
extern void ftape_reset_position( void);
extern void udelay( int usecs);
extern int udelay_calibrate( void);
extern int ftape_seek_to_bot( void);

#endif

==> ftape-2.03b.tar.gz: ftape-2.03b/ftape-io.h <==
#ifndef _FTAPE_IO_H
#define _FTAPE_IO_H

/*
 * Copyright (C) 1993-1995 Bas Laarhoven.

This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2, or (at your option)
any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; see the file COPYING.  If not, write to
the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.

 *
 $Source: /home/bas/distr/ftape-2.03b/RCS/ftape-io.h,v $
 $Author: bas $
 *
 $Revision: 1.36 $
 $Date: 1995/05/06 16:11:53 $
 $State: Beta $
 *
 *      This file contains definitions for the glue part
 *      of the QIC-40/80 floppy-tape driver for Linux.
 */

#include "vendors.h"

typedef struct {
  unsigned seek;
  unsigned reset;
  unsigned rewind;
  unsigned head_seek;
  unsigned stop;
  unsigned pause;
} timeout_table;

/*
 *      ftape-io.c defined global vars.
 */
extern timeout_table timeout;
extern int qic_std;
extern int tape_len;
extern volatile int current_command;
extern const struct qic117_command_table qic117_cmds[];
extern int might_be_off_track;

/*
 *      ftape-io.c defined global functions.
 */
extern void udelay( int usecs);
extern int udelay_calibrate( void);
extern void ftape_sleep( unsigned int time);
extern void ftape_report_vendor_id( unsigned int* id);
extern int ftape_command( int command);
extern int ftape_command_wait( int command, int timeout, int* status);
extern int ftape_report_drive_status( int *status);
extern int ftape_report_raw_drive_status( int *status);
extern int ftape_report_status( int* status);
extern int ftape_interrupt_wait( int time);
extern int ftape_ready_wait( int timeout, int* status);
extern int ftape_seek_head_to_track( int track);
extern int ftape_parameter( int command);
extern int ftape_in_error_state( int status);
extern int ftape_set_data_rate( int rate);
extern int ftape_report_error( int* error, int* command, int report);
extern int ftape_reset_drive( void);
extern int ftape_put_drive_to_sleep( vendor_struct drive_type);
extern int ftape_wakeup_drive( wake_up_types method);

#endif
